<!--
SPDX-FileCopyrightText: © 2023 Nikita Karamov <me@kytta.dev>
SPDX-License-Identifier: CC-BY-4.0 OR BSD-2-Clause
-->
<!-- markdownlint-disable MD024 -->

# bumerge changelog

## [0.2.0] - 2023-04-28

### Added

- [#6](https://github.com/kytta/bumerge/pull/6):
  Validation of the `version` and `variant` fields

## [0.1.0] - 2023-04-28

### Added

- [#4](https://github.com/kytta/bumerge/pull/4):
  Basic configuration merging

<!-- Per-version diffs -->

[0.2.0]: https://github.com/kytta/bumerge/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/kytta/bumerge/compare/386c01fe45029a6d6ef1185cd364a37040795e26...v0.1.0
